pub(crate) struct ConsoleEndpoint {
downstream: Sender<Option<Arc<Vec<u8>>>>,
upstream_event: Sender<ConsoleEvent>,
close_oneshot: Option<Sender<()>>,
}Expand description
The ConsoleEndpoint handles communication with MELVINs operator console.
Fields
downstream: Sender<Option<Arc<Vec<u8>>>>Used to send downstream messages to connected consoles.
upstream_event: Sender<ConsoleEvent>Used to broadcast upstream events from consoles.
close_oneshot: Option<Sender<()>>A channel sender to trigger endpoint shutdown.
Implementations
Sourceimpl ConsoleEndpoint
impl ConsoleEndpoint
Sourceasync fn handle_connection_rx(
socket: &mut ReadHalf<'_>,
upstream_event_sender: &Sender<ConsoleEvent>,
) -> Result<(), Error>
async fn handle_connection_rx( socket: &mut ReadHalf<'_>, upstream_event_sender: &Sender<ConsoleEvent>, ) -> Result<(), Error>
Handles incoming data from the connected console. It listens for messages and broadcasts them as upstream events.
Arguments
socket: The reading end of the connection.upstream_event_sender: The sender used to broadcast received upstream events.
Errors
Returns I/O errors if issues arise when reading data from the socket.
Sourceasync fn handle_connection_tx(
socket: &mut WriteHalf<'_>,
downstream_receiver: &mut Receiver<Option<Arc<Vec<u8>>>>,
) -> Result<(), Error>
async fn handle_connection_tx( socket: &mut WriteHalf<'_>, downstream_receiver: &mut Receiver<Option<Arc<Vec<u8>>>>, ) -> Result<(), Error>
Handles sending downstream messages to the connected console. It listens to a receiver for messages and sends them to the console.
Arguments
socket: The write end of the connection.downstream_receiver: A receiver to get downstream messages.
Errors
Returns I/O errors if issues arise when sending data to the socket.
Sourcepub(crate) fn send_downstream(&self, msg: DownstreamContent)
pub(crate) fn send_downstream(&self, msg: DownstreamContent)
Sends a downstream message to the operator console.
Arguments
msg: ADownstreamContentmessage to send.
Sourcepub(crate) fn is_console_connected(&self) -> bool
pub(crate) fn is_console_connected(&self) -> bool
Checks whether any console is currently connected to the endpoint.
Returns
true if at least one console is connected; otherwise, false.
Sourcepub(crate) fn subscribe_upstream_events(&self) -> Receiver<ConsoleEvent>
pub(crate) fn subscribe_upstream_events(&self) -> Receiver<ConsoleEvent>
Subscribes to upstream events from the connected console.
Returns
A broadcast receiver to listen for upstream events.